/* $Id: obuf_stderr.c 616 2005-08-19 20:11:01Z bruce $ */
#include <unistd.h>
#include "obuf.h"

static char buffer[4096];

/** Output buffer for \c stderr */
obuf errbuf = { { 2, buffer, 4096, 0, 0, 0, 0, IOBUF_NEEDSCLOSE, 0 },
		0, 0, (obuf_fn)write };
